Index: src/tests/.expect/ifcond.txt
===================================================================
--- src/tests/.expect/ifcond.txt	(revision 41770ed102327cb6d1d192134987c43c9c07fd30)
+++ 	(revision )
@@ -1,4 +1,0 @@
-x != 0 correct
-x != 0 && y != 0 correct
-x == y correct
-s.i < 4 correct
Index: src/tests/.expect/ifwhileCtl.txt
===================================================================
--- src/tests/.expect/ifwhileCtl.txt	(revision 174845ed867246025234e5bf64bc7af2c721b608)
+++ src/tests/.expect/ifwhileCtl.txt	(revision 174845ed867246025234e5bf64bc7af2c721b608)
@@ -0,0 +1,7 @@
+x != 0 correct
+x != 0 && y != 0 correct
+x == y correct
+s.i < 4 correct
+x != 0 correct
+x == y correct
+s.i < 4 correct
Index: src/tests/ifcond.c
===================================================================
--- src/tests/ifcond.c	(revision 41770ed102327cb6d1d192134987c43c9c07fd30)
+++ 	(revision )
@@ -1,53 +1,0 @@
-//
-// Cforall Version 1.0.0 Copyright (C) 2017 University of Waterloo
-//
-// The contents of this file are covered under the licence agreement in the
-// file "LICENCE" distributed with Cforall.
-//
-// ifcond.c --
-//
-// Author           : Peter A. Buhr
-// Created On       : Sat Aug 26 10:13:11 2017
-// Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Jun  2 09:55:02 2018
-// Update Count     : 15
-//
-
-#include <fstream>
-
-int f( int r ) { return r; }
-
-int main( void ) {
-	int x = 4, y = 3;
-
-	if ( int x = 1 ) {
-		sout | "x != 0 correct" | endl;
-	} else {
-		sout | "x == 0 incorrect" | endl;
-	} // if
-
-	if ( int x = 4, y = 0 ) {
-		sout | "x != 0 && y != 0 incorrect" | endl;
-	} else if ( int x = 4, y = 1 ) {
-		sout | "x != 0 && y != 0 correct" | endl;
-	} else {
-		sout | "x == 0 || y == 0 incorrect" | endl;
-	} // if
-
-	if ( int x = 5, y = f( x ); x == y ) {
-		sout | "x == y correct" | endl;
-	} else {
-		sout | "x != y incorrect" | endl;
-	} // if
-
-	if ( struct S { int i; } s = { 3 }; s.i < 4 ) {
-		sout | "s.i < 4 correct" | endl;
-	} else {
-		sout | "s.i >= 4 incorrect" | endl;
-	} // if
-} // main
-
-// Local Variables: //
-// tab-width: 4 //
-// compile-command: "cfa ifcond.c" //
-// End: //
Index: src/tests/ifwhileCtl.c
===================================================================
--- src/tests/ifwhileCtl.c	(revision 174845ed867246025234e5bf64bc7af2c721b608)
+++ src/tests/ifwhileCtl.c	(revision 174845ed867246025234e5bf64bc7af2c721b608)
@@ -0,0 +1,75 @@
+//
+// Cforall Version 1.0.0 Copyright (C) 2017 University of Waterloo
+//
+// The contents of this file are covered under the licence agreement in the
+// file "LICENCE" distributed with Cforall.
+//
+// ifcond.c --
+//
+// Author           : Peter A. Buhr
+// Created On       : Sat Aug 26 10:13:11 2017
+// Last Modified By : Peter A. Buhr
+// Last Modified On : Mon Jun  4 22:46:48 2018
+// Update Count     : 19
+//
+
+#include <fstream>
+
+int f( int r ) { return r; }
+
+int main( void ) {
+	int x = 4, y = 3;
+
+	if ( int x = 1 ) {
+		sout | "x != 0 correct" | endl;
+	} else {
+		sout | "x == 0 incorrect" | endl;
+	} // if
+
+	if ( int x = 4, y = 0 ) {
+		sout | "x != 0 && y != 0 incorrect" | endl;
+	} else if ( int x = 4, y = 1 ) {
+		sout | "x != 0 && y != 0 correct" | endl;
+	} else {
+		sout | "x == 0 || y == 0 incorrect" | endl;
+	} // if
+
+	if ( int x = 5, y = f( x ); x == y ) {
+		sout | "x == y correct" | endl;
+	} else {
+		sout | "x != y incorrect" | endl;
+	} // if
+
+	if ( struct S { int i; } s = { 3 }; s.i < 4 ) {
+		S s1;
+		sout | "s.i < 4 correct" | endl;
+	} else {
+		S s1;
+		sout | "s.i >= 4 incorrect" | endl;
+	} // if
+
+	while ( int x = 1 ) {
+		sout | "x != 0 correct" | endl;
+		break;
+	} // while
+
+	while ( int x = 4, y = 0 ) {
+		sout | "x != 0 && y != 0 incorrect" | endl;
+	} // while
+
+	while ( int x = 5, y = f( x ); x == y ) {
+		sout | "x == y correct" | endl;
+		break;
+	} // while
+
+	while ( struct S { int i; } s = { 3 }; s.i < 4 ) {
+		S s1;
+		sout | "s.i < 4 correct" | endl;
+		break;
+	} // while
+} // main
+
+// Local Variables: //
+// tab-width: 4 //
+// compile-command: "cfa ifcond.c" //
+// End: //
Index: src/tests/sum.c
===================================================================
--- src/tests/sum.c	(revision 41770ed102327cb6d1d192134987c43c9c07fd30)
+++ src/tests/sum.c	(revision 174845ed867246025234e5bf64bc7af2c721b608)
@@ -11,6 +11,6 @@
 // Created On       : Wed May 27 17:56:53 2015
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Feb 17 11:49:17 2018
-// Update Count     : 273
+// Last Modified On : Sun Jun  3 19:23:41 2018
+// Update Count     : 278
 //
 
@@ -18,8 +18,8 @@
 #include <stdlib>
 
-void ?{}( int & c, zero_t ) { c = 0; }
+void ?{}( int & c, zero_t ) { c = 0; }					// not in prelude
 
 trait sumable( otype T ) {
-	void ?{}( T &, zero_t );							// constructor from 0 literal
+	void ?{}( T &, zero_t );							// 0 literal constructor
 	T ?+?( T, T );										// assortment of additions
 	T ?+=?( T &, T );
@@ -29,7 +29,7 @@
 
 forall( otype T | sumable( T ) )						// use trait
-T sum( unsigned int size, T a[] ) {
-	T total = 0;										// instantiate T from 0 by calling constructor
-	for ( unsigned int i = 0; i < size; i += 1 )
+T sum( size_t size, T a[] ) {
+	T total = 0;										// initialize by 0 constructor
+	for ( size_t i = 0; i < size; i += 1 )
 		total += a[i];									// select appropriate +
 	return total;
@@ -111,8 +111,8 @@
 	for ( int i = 0; i < size; i += 1, v += 1 ) {
 		s += (int)v;
-		gs.x[i] = (int)v;								// set filed array in generic type
+		gs.x[i] = (int)v;								// set field array in generic type
 	} // for
 	sout | "sum from" | low | "to" | High | "is"
-		 | sum( size, gs.x ) | ", check" | (int)s | endl; // add filed array in generic type
+		 | sum( size, gs.x ) | ", check" | (int)s | endl; // add field array in generic type
 } // main
 
